/* XVCL - the xview classes

   XVCL might one day be a hopefully useful class library
   for xview programming in C++. Just now, it slowly grows
   as I write programs, so many many things are missing.

   Copyright (C) 1998 Frank Rustemeyer.
   This file is part of the Emperor package.

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2 of the
   License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330, Boston,
   MA 02111-1307, USA.

   If you have changes and you want them to be included in a future
   release of Emperor, please e-mail them to mambres@mud.tap.de.

   This file implements some classes for handling pixmaps.

   98/11/30, Frank Rustemeyer <mambres@mud.tap.de>: Released.
*/

#include "xpm.h"

#include <stdio.h>

// ****************************************************** pixmap *********

pixmap::pixmap(Display *disp, char **data)
{   int screen;
    Window root;

    screen = DefaultScreen(disp);
    root = RootWindow(disp, screen);

    attr.valuemask = 0;
    if (XpmCreatePixmapFromData(disp, root, data, &pix, NULL, &attr))
    {    fprintf(stderr, "Error parsing pixmap file.\n");
         exit(1);
         }

    gcval.function = GXcopy;
    gc = XCreateGC(disp, root, GCFunction, &gcval);
    mydisp = disp;  // remember that for the destructor
    } 

pixmap::pixmap(Display *disp, char *file)
{   int screen;
    Window root;

    screen = DefaultScreen(disp);
    root = RootWindow(disp, screen);

    attr.valuemask = 0;
    if (XpmReadFileToPixmap(disp, root, file, &pix, NULL, &attr))
    {    fprintf(stderr, "Error parsing pixmap file.\n");
         exit(1);
         }

    gcval.function = GXcopy;
    gc = XCreateGC(disp, root, GCFunction, &gcval);
    mydisp = disp;  // remember that for the destructor
    }

pixmap::~pixmap(void)
{   XFreeGC(mydisp, gc);
    }

void pixmap::display(Display *disp, Drawable wnd, int x, int y, 
                     int width, int height, int to_x, int to_y)
{   XCopyArea(disp, pix, wnd, gc, x, y, width, height, to_x, to_y);
    }

// *************************************************** pixmask **********

pixmask::pixmask(Display *disp, char **data)
{   int screen;
    Window root;

    screen = DefaultScreen(disp);
    root = RootWindow(disp, screen);

    attr.valuemask = 0;
    if (XpmCreatePixmapFromData(disp, root, data, &pix, &msk, &attr))
    {    fprintf(stderr, "Error parsing pixmap file.\n");
         exit(1);
         }

    gcval.function = GXand;
    gcval.foreground = 0;
    gcval.background = ~0;
    maskgc = XCreateGC(disp, root, GCFunction | GCForeground | GCBackground, &gcval);
    gcval.function = GXor;
    gc = XCreateGC(disp, root, GCFunction, &gcval);

    mydisp = disp;  // remember that for the destructor
    }

pixmask::~pixmask(void)
{   XFreeGC(mydisp, maskgc);
    XFreeGC(mydisp, gc);
    }

void pixmask::display(Display *disp, Drawable wnd, int x, int y,
                     int width, int height, int to_x, int to_y)
{   XCopyPlane(disp, msk, wnd, maskgc, x, y, width, height, to_x, to_y, 1); 
    XCopyArea(disp, pix, wnd, gc, x, y, width, height, to_x, to_y);
    }

 

